import {configureStore, createSlice, createAsyncThunk} from "@reduxjs/toolkit";

let msgSlice = createSlice({
    name: "msgSlice",
    initialState: {
        msg: "redux toolkit state msg"
    },
    reducers: {
        changeMsg(state, action){
            state.msg = action.payload
        }
    }
})

// 第一个参数为名称
// 第二个为异步方法
export let changeCountThunk = createAsyncThunk("countSlice/changeCountThunk",async (params)=>{
    return await new Promise(resolve => {
        console.log("changeCountThunk params", params)

        setTimeout(()=>{
            resolve(params)
        },500)
    })
})

let countSlice = createSlice({
    name: "countSlice",
    initialState: {
        count: 0
    },
    reducers: {
        addCount(state, action){
            state.count+=1
        }
    },
    extraReducers:(chunk)=>{
        chunk.addCase(changeCountThunk.pending, ()=>{
            console.log("changeCountThunk pending")
        }).addCase(changeCountThunk.fulfilled, (state, action)=>{
            state.count = action.payload
        })
    }
    // 废弃
    // extraReducers: {
    //     [changeCountThunk.pending]: ()=>{
    //         console.log("changeCountThunk pending")
    //     },
    //     [changeCountThunk.fulfilled]: (state, action)=>{
    //         state.count = action.payload
    //     }
    // }
})



let store = configureStore({
    reducer: {
        msgReducer: msgSlice.reducer,
        countReducer: countSlice.reducer
    }
})

export default store;

export const {
    changeMsg
} = msgSlice.actions

export const {
    addCount
} = countSlice.actions
